==> react-molecule-badge-counter-1.5.0.tgz: package/lib/index.js <==
import React from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
var BASE_CLASS = "sui-MoleculeBadgeCounter";
var CLASS_WITH_CHILDREN = BASE_CLASS + "--withChildren";
var CLASS_BULLET = BASE_CLASS + "-bullet";
var CLASS_SMALL = CLASS_BULLET + "-small";
var CLASS_MEDIUM = CLASS_BULLET + "-medium";
var CLASS_LARGE = CLASS_BULLET + "-large";
var CLASS_CUSTOM = CLASS_BULLET + "-custom";
var CLASS_MEDIUM_THREE_CHARS = CLASS_MEDIUM + "--threeCharacters";
var CLASS_LARGE_THREE_CHARS = CLASS_LARGE + "--threeCharacters";
var SIZES = {
  SMALL: 'small',
  MEDIUM: 'medium',
  LARGE: 'large'
};
var VARIANTS = {
  DOT: 'dot',
  EXCLAMATION: 'exclamation'
};
var MAX_LABEL = '+99';

var MoleculeBadgeCounter = function MoleculeBadgeCounter(_ref) {
  var _cx, _cx2;

  var children = _ref.children,
      _ref$custom = _ref.custom,
      custom = _ref$custom === void 0 ? false : _ref$custom,
      _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      size = _ref.size,
      variant = _ref.variant;
  var hasLabel = Boolean(label);
  var hasChildren = Boolean(children);
  var CLASS_SIZE = getClassSize({
    size: size,
    hasLabel: hasLabel
  });
  var CLASS_LENGTH_LABEL = getClassLengthLabel({
    hasLabel: hasLabel,
    label: label,
    size: size
  });
  var CLASS_VARIANT = variant ? CLASS_BULLET + "-" + variant : '';
  var className = cx(BASE_CLASS, (_cx = {}, _cx[CLASS_WITH_CHILDREN] = hasChildren, _cx));
  var processedLabel = label.length >= 3 ? MAX_LABEL : label;
  var classNameBullet = cx(CLASS_BULLET, CLASS_SIZE, CLASS_VARIANT, CLASS_LENGTH_LABEL, (_cx2 = {}, _cx2[CLASS_CUSTOM] = custom, _cx2[CLASS_WITH_CHILDREN] = Boolean(children), _cx2));
  return /*#__PURE__*/React.createElement("span", {
    className: className
  }, /*#__PURE__*/React.createElement("span", {
    className: classNameBullet
  }, processedLabel), /*#__PURE__*/React.createElement("span", null, children));
};

var getClassSize = function getClassSize(_ref2) {
  var size = _ref2.size,
      hasLabel = _ref2.hasLabel;

  if (hasLabel && (size === SIZES.SMALL || !size) || size === SIZES.MEDIUM) {
    return CLASS_MEDIUM;
  } else if (size === SIZES.LARGE) {
    return CLASS_LARGE;
  }

  return CLASS_SMALL;
};

var getClassLengthLabel = function getClassLengthLabel(_ref3) {
  var hasLabel = _ref3.hasLabel,
      label = _ref3.label,
      size = _ref3.size;
  if (!hasLabel || (label + '').length < 3) return '';
  if (size === SIZES.MEDIUM) return CLASS_MEDIUM_THREE_CHARS;
  return CLASS_LARGE_THREE_CHARS;
};

MoleculeBadgeCounter.displayName = 'MoleculeBadgeCounter';
export default MoleculeBadgeCounter;
export { SIZES as moleculeBadgeCounterSizes, VARIANTS as moleculeBadgeCounterVariants };

==> react-molecule-badge-counter-1.7.0.tgz: package/lib/index.js <==
import React from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
var BASE_CLASS = "sui-MoleculeBadgeCounter";
var CLASS_WITH_CHILDREN = BASE_CLASS + "--withChildren";
var CLASS_BULLET = BASE_CLASS + "-bullet";
var CLASS_SMALL = CLASS_BULLET + "-small";
var CLASS_MEDIUM = CLASS_BULLET + "-medium";
var CLASS_LARGE = CLASS_BULLET + "-large";
var CLASS_DISABLED = 'is-disabled';
var CLASS_SELECTED = 'is-selected';
var CLASS_MEDIUM_THREE_CHARS = CLASS_MEDIUM + "--threeCharacters";
var CLASS_LARGE_THREE_CHARS = CLASS_LARGE + "--threeCharacters";
var SIZES = {
  SMALL: 'small',
  MEDIUM: 'medium',
  LARGE: 'large'
};
var STATUS = {
  DEFAULT: 'default',
  DISABLED: 'disabled',
  SELECTED: 'selected'
};
var VARIANTS = {
  DOT: 'dot',
  EXCLAMATION: 'exclamation'
};
var MAX_LABEL = '+99';

var MoleculeBadgeCounter = function MoleculeBadgeCounter(_ref) {
  var _cx, _cx2;

  var children = _ref.children,
      _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      size = _ref.size,
      status = _ref.status,
      variant = _ref.variant;
  var hasLabel = Boolean(label);
  var hasChildren = Boolean(children);
  var CLASS_SIZE = getClassSize({
    size: size,
    hasLabel: hasLabel
  });
  var CLASS_STATUS = getClassStatus({
    status: status
  });
  var CLASS_LENGTH_LABEL = getClassLengthLabel({
    hasLabel: hasLabel,
    label: label,
    size: size
  });
  var CLASS_VARIANT = variant ? CLASS_BULLET + "-" + variant : '';
  var className = cx(BASE_CLASS, (_cx = {}, _cx[CLASS_WITH_CHILDREN] = hasChildren, _cx));
  var processedLabel = label.length >= 3 ? MAX_LABEL : label;
  var classNameBullet = cx(CLASS_BULLET, CLASS_SIZE, CLASS_STATUS, CLASS_VARIANT, CLASS_LENGTH_LABEL, (_cx2 = {}, _cx2[CLASS_WITH_CHILDREN] = Boolean(children), _cx2));
  return /*#__PURE__*/React.createElement("span", {
    className: className
  }, /*#__PURE__*/React.createElement("span", {
    className: classNameBullet
  }, processedLabel), /*#__PURE__*/React.createElement("span", null, children));
};

var getClassSize = function getClassSize(_ref2) {
  var size = _ref2.size,
      hasLabel = _ref2.hasLabel;

  if (hasLabel && (size === SIZES.SMALL || !size) || size === SIZES.MEDIUM) {
    return CLASS_MEDIUM;
  } else if (size === SIZES.LARGE) {
    return CLASS_LARGE;
  }

  return CLASS_SMALL;
};

var getClassStatus = function getClassStatus(_ref3) {
  var status = _ref3.status;
  if (status === STATUS.DISABLED) return CLASS_DISABLED;
  if (status === STATUS.SELECTED) return CLASS_SELECTED;
  return '';
};

var getClassLengthLabel = function getClassLengthLabel(_ref4) {
  var hasLabel = _ref4.hasLabel,
      label = _ref4.label,
      size = _ref4.size;
  if (!hasLabel || (label + '').length < 3) return '';
  if (size === SIZES.MEDIUM) return CLASS_MEDIUM_THREE_CHARS;
  return CLASS_LARGE_THREE_CHARS;
};

MoleculeBadgeCounter.displayName = 'MoleculeBadgeCounter';
export default MoleculeBadgeCounter;
export { SIZES as moleculeBadgeCounterSizes, STATUS as moleculeBadgeCounterStatus, VARIANTS as moleculeBadgeCounterVariants };
